@@ -2,7 +2,7 @@
 package MooseX::Getopt::Usage;
 
 use 5.010;
-our $VERSION = '0.12_01';
+our $VERSION = '0.12_02';
 
 use Moose::Role;
 use Try::Tiny;
@@ -72,20 +72,20 @@ around new_with_options => sub {
         return $self;
     }
     catch {
-        when (
+        if (
             /Attribute \((\w+)\) does not pass the type constraint because: (.*?) at/
         ) {
             $class->getopt_usage( exit => 1, err => "Invalid '$1' : $2" );
         }
-        when (/Attribute \((\w+)\) is required /) {
+        elsif (/Attribute \((\w+)\) is required /) {
             $class->getopt_usage( exit => 2, err => "Required option missing: $1" );
         }
-        when (/^Unknown option:|^Value .*? for option |Option .* does not take an argument/) {
+        elsif (/^Unknown option:|^Value .*? for option |Option .* does not take an argument/) {
             # Getopt::Long warnings we promoted in _getopt_spec_warnings
             s/\n+$//;
             $class->getopt_usage( exit => 3, err => $_ );
         }
-        default {
+        else {
             die $_;
         }
     };
@@ -104,7 +104,7 @@ MooseX::Getopt::Usage - Extend MooseX::Getopt with usage message and man page ge
 
 =head1 VERSION
 
-Version 0.12_01
+Version 0.12_02
 
 =head1 SYNOPSIS
 
@@ -452,7 +452,7 @@ Put this is a file called hello.pl and make it executable.
 
  #!/usr/bin/env perl
  package Hello;
- use Modern::Perl;
+ use 5.010;
  use Moose;
 
  with 'MooseX::Getopt::Usage';
